The geometry Module
===================

.. automodule:: cfel_fmt.geometry
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: TypeBeam, TypePanel, TypeBadRegion, TypeDetector
